@@ -11,20 +11,24 @@ use std::sync::Arc;
 #[derive(Copy, Clone, Debug, PartialEq, Eq)]
 pub(crate) enum Bop {
     Plus,
+    ImplicitPlus,
     Minus,
     Mul,
     Div,
     Mod,
+    Pow,
 }
 
 impl fmt::Display for Bop {
     fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
         match self {
             Self::Plus => write!(f, "+"),
+            Self::ImplicitPlus => write!(f, " "),
             Self::Minus => write!(f, "-"),
             Self::Mul => write!(f, "*"),
             Self::Div => write!(f, "/"),
             Self::Mod => write!(f, " mod "),
+            Self::Pow => write!(f, "^"),
         }
     }
 }
@@ -39,7 +43,6 @@ pub(crate) enum Expr {
     UnaryDiv(Box<Expr>),
     Factorial(Box<Expr>),
     Bop(Bop, Box<Expr>, Box<Expr>),
-    Pow(Box<Expr>, Box<Expr>),
     // Call a function or multiply the expressions
     Apply(Box<Expr>, Box<Expr>),
     // Call a function, or throw an error if lhs is not a function
@@ -74,7 +77,6 @@ impl<'a> Expr {
             Self::Bop(op, a, b) => {
                 format!("({}{}{})", a.format(ctx, int)?, op, b.format(ctx, int)?)
             }
-            Self::Pow(a, b) => format!("({}^{})", a.format(ctx, int)?, b.format(ctx, int)?),
             Self::Apply(a, b) => format!("({} ({}))", a.format(ctx, int)?, b.format(ctx, int)?),
             Self::ApplyFunctionCall(a, b) | Self::ApplyMul(a, b) => {
                 format!("({} {})", a.format(ctx, int)?, b.format(ctx, int)?)
@@ -154,23 +156,7 @@ pub(crate) fn evaluate<I: Interrupt>(
                 _ => return Err(FendError::InvalidOperandsForSubtraction),
             }
         }
-        Expr::Bop(bop, a, b) => eval!(*a)?.handle_two_nums(
-            eval!(*b)?,
-            |a, b| a.bop(bop, b, int),
-            |a| |f| Expr::Bop(bop, f, Box::new(Expr::Literal(Value::Num(Box::new(a))))),
-            |a| |f| Expr::Bop(bop, Box::new(Expr::Literal(Value::Num(Box::new(a)))), f),
-            scope,
-        )?,
-        Expr::Apply(a, b) | Expr::ApplyMul(a, b) => {
-            if let (Expr::Ident(a), Expr::Ident(b)) = (&*a, &*b) {
-                let ident = format!("{}_{}", a, b);
-                if let Ok(val) = crate::units::query_unit_static(&ident, context, int) {
-                    return Ok(val);
-                }
-            }
-            eval!(*a)?.apply(*b, ApplyMulHandling::Both, scope, context, int)?
-        }
-        Expr::Pow(a, b) => {
+        Expr::Bop(Bop::Pow, a, b) => {
             let lhs = eval!(*a)?;
             if should_compute_inverse(&*b) {
                 let result = match &lhs {
@@ -185,11 +171,43 @@ pub(crate) fn evaluate<I: Interrupt>(
             lhs.handle_two_nums(
                 eval!(*b)?,
                 |a, b| a.pow(b, int),
-                |a| |f| Expr::Pow(f, Box::new(Expr::Literal(Value::Num(Box::new(a))))),
-                |a| |f| Expr::Pow(Box::new(Expr::Literal(Value::Num(Box::new(a)))), f),
+                |a| {
+                    |f| {
+                        Expr::Bop(
+                            Bop::Pow,
+                            f,
+                            Box::new(Expr::Literal(Value::Num(Box::new(a)))),
+                        )
+                    }
+                },
+                |a| {
+                    |f| {
+                        Expr::Bop(
+                            Bop::Pow,
+                            Box::new(Expr::Literal(Value::Num(Box::new(a)))),
+                            f,
+                        )
+                    }
+                },
                 scope,
             )?
         }
+        Expr::Bop(bop, a, b) => eval!(*a)?.handle_two_nums(
+            eval!(*b)?,
+            |a, b| a.bop(bop, b, context, int),
+            |a| |f| Expr::Bop(bop, f, Box::new(Expr::Literal(Value::Num(Box::new(a))))),
+            |a| |f| Expr::Bop(bop, Box::new(Expr::Literal(Value::Num(Box::new(a)))), f),
+            scope,
+        )?,
+        Expr::Apply(a, b) | Expr::ApplyMul(a, b) => {
+            if let (Expr::Ident(a), Expr::Ident(b)) = (&*a, &*b) {
+                let ident = format!("{}_{}", a, b);
+                if let Ok(val) = crate::units::query_unit_static(&ident, context, int) {
+                    return Ok(val);
+                }
+            }
+            eval!(*a)?.apply(*b, ApplyMulHandling::Both, scope, context, int)?
+        }
         Expr::ApplyFunctionCall(a, b) => {
             eval!(*a)?.apply(*b, ApplyMulHandling::OnlyApply, scope, context, int)?
         }
