@@ -200,7 +200,12 @@ const CONSTANTS: &[UnitTuple] = &[
         "=299792458 m/s",
         "speed of light in vacuum (exact)",
     ),
-    ("h", "", "s@=6.62607015e-34 J s", "Planck constant (exact)"),
+    (
+        "planck",
+        "",
+        "=6.62607015e-34 J s",
+        "Planck constant (exact)",
+    ),
     (
         "boltzmann",
         "",
@@ -355,6 +360,7 @@ const TIME_UNITS: &[UnitTuple] = &[
     ("min", "mins", "s@minute", ""),
     ("hour", "hours", "l@60 minutes", ""),
     ("hr", "hrs", "s@hour", ""),
+    ("h", "h", "s@hour", ""),
     ("day", "days", "l@24 hours", ""),
     ("d", "", "s@day", ""),
     ("da", "", "s@day", ""),
@@ -566,6 +572,7 @@ const IMPERIAL_ABBREVIATIONS: &[UnitTuple] = &[
     ("mph", "", "mile/hr", ""),
     ("mpg", "", "mile/gal", ""),
     ("kph", "", "km/hr", ""),
+    ("kmh", "", "km/hr", ""),
     ("fpm", "", "ft/min", ""),
     ("fps", "", "ft/s", ""),
     ("rpm", "", "rev/min", ""),
@@ -750,7 +757,7 @@ mod tests {
         if s.is_empty() || s == "'" || s == "\"" {
             return;
         }
-        eprintln!("Testing '{}'", s);
+        //eprintln!("Testing '{s}'");
         crate::evaluate(s, ctx).unwrap();
     }
 
